@@ -27,6 +27,7 @@ class Changelog:
             raise NotAGitProjectError()
 
         self.config: BaseConfig = config
+        self.encoding = self.config.settings["encoding"]
         self.cz = factory.commiter_factory(self.config)
 
         self.start_rev = args.get("start_rev") or self.config.settings.get(
@@ -101,7 +102,7 @@ class Changelog:
             )
 
         changelog_hook: Callable | None = self.cz.changelog_hook
-        with smart_open(self.file_name, "w") as changelog_file:
+        with smart_open(self.file_name, "w", encoding=self.encoding) as changelog_file:
             partial_changelog: str | None = None
             if self.incremental:
                 new_lines = changelog.incremental_build(
@@ -141,7 +142,11 @@ class Changelog:
 
         end_rev = ""
         if self.incremental:
-            changelog_meta = changelog.get_metadata(self.file_name, self.scheme)
+            changelog_meta = changelog.get_metadata(
+                self.file_name,
+                self.scheme,
+                encoding=self.encoding,
+            )
             latest_version = changelog_meta.get("latest_version")
             if latest_version:
                 latest_tag_version: str = bump.normalize_tag(
@@ -187,7 +192,7 @@ class Changelog:
 
         lines = []
         if self.incremental and os.path.isfile(self.file_name):
-            with open(self.file_name, "r") as changelog_file:
+            with open(self.file_name, "r", encoding=self.encoding) as changelog_file:
                 lines = changelog_file.readlines()
 
         self.write_changelog(changelog_out, lines, changelog_meta)
