@@ -17,7 +17,7 @@ class YAMLConfig(BaseConfig):
         self.add_path(path)
 
     def init_empty_config_content(self):
-        with smart_open(self.path, "a") as json_file:
+        with smart_open(self.path, "a", encoding=self.encoding) as json_file:
             yaml.dump({"commitizen": {}}, json_file, explicit_start=True)
 
     def _parse_setting(self, data: bytes | str) -> None:
@@ -44,7 +44,7 @@ class YAMLConfig(BaseConfig):
             parser = yaml.load(yaml_file, Loader=yaml.FullLoader)
 
         parser["commitizen"][key] = value
-        with smart_open(self.path, "w") as yaml_file:
+        with smart_open(self.path, "w", encoding=self.encoding) as yaml_file:
             yaml.dump(parser, yaml_file, explicit_start=True)
 
         return self
